/***************************************************************************
                          ann_term.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_TERM_H
#define __ANN_TERM_H

#include <ann_array.h>
#include <ann_use_nan.h>

namespace ANN
{

  typedef Array<double> Term; /* training set term (weak container) */
  typedef ARRAY<double> TERM; /* training set term (strong container) */
  
} // namespace ANN

#endif /* __ANN_TERM_H */
